@@ -19,6 +19,7 @@ use std::process::{Command, Stdio};
 use std::str;
 use std::{env, fs::File};
 
+mod ansi;
 mod commit_line;
 mod constants;
 mod line_collector;
@@ -71,38 +72,41 @@ fn highlight_diff<W: io::Write + Send + 'static>(input: &mut dyn io::Read, outpu
 
     // Read input line by line, using from_utf8_lossy() to convert lines into
     // strings while handling invalid UTF-8 without crashing
-    let mut line_bytes: Vec<u8> = Vec::new();
-    let mut buf: [u8; 1] = [0];
+    let mut line: Vec<u8> = Vec::new();
+    let mut buf: [u8; 16384] = [0; 16384];
     loop {
         let result = input.read(&mut buf);
         if result.is_err() {
             panic!("Error reading input stream: {:?}", result.err().unwrap());
         }
 
-        if result.unwrap() == 0 {
+        let read_count = result.unwrap();
+        if read_count == 0 {
             // End of stream
-            if !line_bytes.is_empty() {
+            if !line.is_empty() {
                 // Stuff found on the last line without a trailing newline
-                line_collector.consume_line(String::from_utf8_lossy(&line_bytes).to_string());
+                line_collector.consume_line(&mut line);
             }
             break;
         }
 
-        let single_byte = buf[0];
-        if single_byte as char == '\r' {
-            // MS-DOS file, LF coming up, just ignore this
-            continue;
-        }
-        if single_byte as char != '\n' {
-            // Line contents, store and continue
-            line_bytes.push(single_byte);
-            continue;
-        }
+        for byte in buf.iter().take(read_count) {
+            let byte = *byte;
+            if byte == b'\r' {
+                // MS-DOS file, LF coming up, just ignore this
+                continue;
+            }
+            if byte != b'\n' {
+                // Line contents, store and continue
+                line.push(byte);
+                continue;
+            }
 
-        // Line finished, consume it!
-        line_collector.consume_line(String::from_utf8_lossy(&line_bytes).to_string());
-        line_bytes.clear();
-        continue;
+            // Line finished, consume it!
+            line_collector.consume_line(&mut line);
+            line.clear();
+            continue;
+        }
     }
 }
 
@@ -390,7 +394,7 @@ mod tests {
     use crate::constants::*;
 
     use super::*;
-    use std::fs;
+    use std::{fs, path::PathBuf};
 
     #[cfg(test)]
     use pretty_assertions::assert_eq;
@@ -448,13 +452,28 @@ mod tests {
         }
         assert!(testdata_path.is_dir());
 
-        // Iterate all files in there
-        let mut failing_example: Option<String> = None;
-        let mut failing_example_expected = vec![];
-        let mut failing_example_actual = vec![];
+        // Find all .diff example files
+        let mut diff_example_files: Vec<PathBuf> = vec![];
         for diff in fs::read_dir(&testdata_path).unwrap() {
             let diff = diff.unwrap();
             let diff = diff.path();
+            if !diff.is_file() {
+                continue;
+            }
+
+            if diff.extension().unwrap() != "diff" {
+                continue;
+            }
+
+            diff_example_files.push(diff);
+        }
+        diff_example_files.sort();
+
+        // Iterate over all the example files
+        let mut failing_example: Option<String> = None;
+        let mut failing_example_expected = vec![];
+        let mut failing_example_actual = vec![];
+        for diff in diff_example_files {
             let diff = diff.as_path();
             if !diff.is_file() {
                 continue;
